import ArtalkConfig from 'artalk/types/artalk-config.js';
import { B as BaseCommentOptions, d as GiscusOptions } from './giscus-af5b3f3b.js';
import { WalineInitOptions } from '@waline/client';

type ArtalkOptions = BaseCommentOptions & Partial<Omit<ArtalkConfig.default, "el" | "pageKey">>;

interface TwikooInitOptions {
    /**
     * Environment ID for tencloud or Link for Vercel
     *
     * 腾讯云环境链接或 Vercel Link
     */
    envId: string;
    /**
     * Tencloud region
     *
     * 腾讯云区域
     *
     * @default "ap-shanghai"
     */
    region?: string;
}
type TwikooOptions = BaseCommentOptions & TwikooInitOptions;

interface WalineOptions extends BaseCommentOptions, Omit<WalineInitOptions, "el" | "comment" | "locale"> {
    /**
     * Whether enable page views count by default
     *
     * 是否启用访问量
     *
     * @default true
     */
    pageview?: boolean;
}

declare const defineArtalkConfig: (options: ArtalkOptions) => void;
declare const defineGiscusConfig: (options: GiscusOptions) => void;
declare const defineTwikooConfig: (options: TwikooOptions) => void;
declare const defineWalineConfig: (options: WalineOptions) => void;

export { defineArtalkConfig, defineGiscusConfig, defineTwikooConfig, defineWalineConfig };
